[gimp/metadata-browser] app: Add import type as third preference on Export



commit 13460aaf6c1faea385d5b18d2bf1894fd7f71606
Author: Alexia Death <alexiadeath gmail com>
Date:   Wed Jan 4 21:06:28 2012 +0200

    app: Add import type as third preference on Export

 app/widgets/gimpfiledialog.c |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)
---
diff --git a/app/widgets/gimpfiledialog.c b/app/widgets/gimpfiledialog.c
index 914b5cd..0603856 100644
--- a/app/widgets/gimpfiledialog.c
+++ b/app/widgets/gimpfiledialog.c
@@ -634,14 +634,17 @@ gimp_file_dialog_set_save_image (GimpFileDialog *dialog,
       /* Priority of default type/extension for Export:
        *
        *   1. Type of last Export
        *   3. Type of latest Export of any document
        *   2. .png
        */
       ext_uri = gimp_image_get_exported_uri (image);
 
       if (! ext_uri)
         ext_uri = g_object_get_data (G_OBJECT (gimp),
                                      GIMP_FILE_EXPORT_LAST_URI_KEY);
+      if (! ext_uri)
+        ext_uri = gimp_image_get_imported_uri (image);
 
       if (! ext_uri)
         ext_uri = "file:///we/only/care/about/extension.png";
@@ -634,14 +634,17 @@ gimp_file_dialog_set_save_image (GimpFileDialog *dialog,
        *
        *   1. Type of last Export
-       *   3. Type of latest Export of any document
-       *   2. .png
+       *   2. Type of latest Export of any document
+       *   3. Type of the image Import
+       *   4. .png
        */
       ext_uri = gimp_image_get_exported_uri (image);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]